Cost DEA model optimizing the input allocation with given prices.
It returns the estimated lambdas as well as the optimal values for inputs and a cost efficiency score
that is the ratio of optimal costs over observed costs.
Usage
costDEA(X, Y, pX, RTS = "crs")
Value
A list object containing the following:
lambdas
Estimated values for the composition of the respective Benchmarks. The lambdas are stored in a matrix with dimensions nrow(X) x nrow(X), where the row is the DMU under observation and the columns are the peers used for the Benchmark.
opt_value
Optimal inputs.
cost_eff
Cost efficiency as the ratio of the optimal cost to the observed cost.
Arguments
X
Vector, matrix or dataframe with DMUs as rows and inputs as columns
Y
Vector, matrix or dataframe with DMUs as rows and outputs as columns
pX
Vector, matrix or dataframe with prices for each DMU and input.
Therefore it must have the same dimensions as X.
RTS
Character string indicating the returns-to-scale, e.g. "crs", "vrs".